#! /usr/bin/env python
# encoding: latin-1

# Indexes into the e_ident array.  Keep synced with
   # http://www.sco.com/developer/gabi/ch4.eheader.html 
EI_MAG0=0	# Magic number, byte 0. 
EI_MAG1=1	# Magic number, byte 1. 
EI_MAG2=2	# Magic number, byte 2. 
EI_MAG3=3	# Magic number, byte 3. 
EI_CLASS=4	# Class of machine. 
EI_DATA=5	# Data format. 
EI_VERSION=6	# ELF format version. 
EI_OSABI=7	# Operating system / ABI identification 
EI_ABIVERSION=8	# ABI version 
OLD_EI_BRAND=8	# Start of architecture identification. 
EI_PAD=9	# Start of padding (per SVR4 ABI). 
EI_NIDENT=16	# Size of e_ident array. 

# Values for the magic number bytes. 
ELFMAG0=0x7f
ELFMAG1='E'
ELFMAG2='L'
ELFMAG3='F'
ELFMAG="\177ELF"	# magic string 
SELFMAG=4		# magic string size 

# Values for e_ident[EI_VERSION] and e_version. 
EV_NONE=0
EV_CURRENT=1

# Values for e_ident[EI_CLASS]. 
ELFCLASSNONE=0	# Unknown class. 
ELFCLASS32=1	# 32-bit architecture. 
ELFCLASS64=2	# 64-bit architecture. 

# Values for e_ident[EI_DATA]. 
ELFDATANONE=0	# Unknown data format. 
ELFDATA2LSB=1	# 2's complement little-endian. 
ELFDATA2MSB=2	# 2's complement big-endian. 

# Values for e_ident[EI_OSABI]. 
ELFOSABI_SYSV=0	# UNIX System V ABI 
ELFOSABI_NONE=ELFOSABI_SYSV	# symbol used in old spec 
ELFOSABI_HPUX=1	# HP-UX operating system 
ELFOSABI_NETBSD=2	# NetBSD 
ELFOSABI_LINUX=3	# GNU/Linux 
ELFOSABI_HURD=4	# GNU/Hurd 
ELFOSABI_86OPEN=5	# 86Open common IA32 ABI 
ELFOSABI_SOLARIS=6	# Solaris 
ELFOSABI_MONTEREY=7	# Monterey 
ELFOSABI_IRIX=8	# IRIX 
ELFOSABI_FREEBSD=9	# FreeBSD 
ELFOSABI_TRU64=10	# TRU64 UNIX 
ELFOSABI_MODESTO=11	# Novell Modesto 
ELFOSABI_OPENBSD=12	# OpenBSD 
ELFOSABI_ARM=97	# ARM 
ELFOSABI_STANDALONE=255	# Standalone (embedded) application 


# Values for e_type. 
ET_NONE=0	# Unknown type. 
ET_REL=1	# Relocatable. 
ET_EXEC=2	# Executable. 
ET_DYN=3	# Shared object. 
ET_CORE=4	# Core file. 

# Values for e_machine. 
EM_NONE=0	# Unknown machine. 
EM_M32=1	# AT&T WE32100. 
EM_SPARC=2	# Sun SPARC. 
EM_386=3	# Intel i386. 
EM_68K=4	# Motorola 68000. 
EM_88K=5	# Motorola 88000. 
EM_486=6	# Intel i486. 
EM_860=7	# Intel i860. 
EM_MIPS=8	# MIPS R3000 Big-Endian only 

# Extensions.  This list is not complete. 
EM_S370=9	# IBM System/370 
EM_MIPS_RS4_BE=10	# MIPS R4000 Big-Endian  /* Depreciated */
EM_PARISC=15	# HPPA 
EM_SPARC32PLUS=18	# SPARC v8plus 
EM_PPC=20	# PowerPC 32-bit 
EM_PPC64=21	# PowerPC 64-bit 
EM_ARM=40	# ARM 
EM_SPARCV9=43	# SPARC v9 64-bit 
EM_IA_64=50	# Intel IA-64 Processor 
EM_X86_64=62	# Advanced Micro Devices x86-64 
EM_ALPHA=0x9026	# Alpha (written in the absence of an ABI 

# Special section indexes. 
SHN_UNDEF=0		# Undefined, missing, irrelevant. 
SHN_LORESERVE=0xff00		# First of reserved range. 
SHN_LOPROC=0xff00		# First processor-specific. 
SHN_HIPROC=0xff1f		# Last processor-specific. 
SHN_ABS=0xfff1		# Absolute values. 
SHN_COMMON=0xfff2		# Common data. 
SHN_HIRESERVE=0xffff		# Last of reserved range. 

# sh_type 
SHT_NULL=0		# inactive 
SHT_PROGBITS=1		# program defined information 
SHT_SYMTAB=2		# symbol table section 
SHT_STRTAB=3		# string table section 
SHT_RELA=4		# relocation section with addends 
SHT_HASH=5		# symbol hash table section 
SHT_DYNAMIC=6		# dynamic section 
SHT_NOTE=7		# note section 
SHT_NOBITS=8		# no space section 
SHT_REL=9		# relocation section - no addends 
SHT_SHLIB=10		# reserved - purpose unknown 
SHT_DYNSYM=11		# dynamic symbol table section 
SHT_NUM=12		# number of section types 
SHT_LOOS=0x60000000	# First of OS specific semantics 
SHT_HIOS=0x6fffffff	# Last of OS specific semantics 
SHT_LOPROC=0x70000000	# reserved range for processor 
SHT_HIPROC=0x7fffffff	# specific section header types 
SHT_LOUSER=0x80000000	# reserved range for application 
SHT_HIUSER=0xffffffff	# specific indexes 

#ARM specific
SHT_ARM_EXIDX=SHT_LOPROC+1  # ARM unwind section.


# Flags for sh_flags. 
SHF_WRITE=0x1		# Section contains writable data. 
SHF_ALLOC=0x2		# Section occupies memory. 
SHF_EXECINSTR=0x4		# Section contains instructions. 
SHF_TLS=0x400		# Section contains TLS data. 
SHF_MASKPROC=0xf0000000	# Reserved for processor-specific. 

# Values for p_type. 
PT_NULL=0	# Unused entry. 
PT_LOAD=1	# Loadable segment. 
PT_DYNAMIC=2	# Dynamic linking information segment. 
PT_INTERP=3	# Pathname of interpreter. 
PT_NOTE=4	# Auxiliary information. 
PT_SHLIB=5	# Reserved (not used). 
PT_PHDR=6	# Location of program header itself. 
PT_TLS=7	# Thread local storage segment 

PT_COUNT=8	# Number of defined p_type values. 

PT_LOOS=0x60000000	# OS-specific 
PT_HIOS=0x6fffffff	# OS-specific 
PT_LOPROC=0x70000000	# First processor-specific type. 
PT_HIPROC=0x7fffffff	# Last processor-specific type. 

# Values for p_flags. 
PF_X=0x1	# Executable. 
PF_W=0x2	# Writable. 
PF_R=0x4	# Readable. 

# Values for d_tag. 
DT_NULL=0	# Terminating entry. 
DT_NEEDED=1	# String table offset of a needed shared
				   # library. 
DT_PLTRELSZ=2	# Total size in bytes of PLT relocations. 
DT_PLTGOT=3	# Processor-dependent address. 
DT_HASH=4	# Address of symbol hash table. 
DT_STRTAB=5	# Address of string table. 
DT_SYMTAB=6	# Address of symbol table. 
DT_RELA=7	# Address of ElfNN_Rela relocations. 
DT_RELASZ=8	# Total size of ElfNN_Rela relocations. 
DT_RELAENT=9	# Size of each ElfNN_Rela relocation entry. 
DT_STRSZ=10	# Size of string table. 
DT_SYMENT=11	# Size of each symbol table entry. 
DT_INIT=12	# Address of initialization function. 
DT_FINI=13	# Address of finalization function. 
DT_SONAME=14	# String table offset of shared object
				   # name. 
DT_RPATH=15	# String table offset of library path. [sup] 
DT_SYMBOLIC=16	# Indicates "symbolic" linking. [sup] 
DT_REL=17	# Address of ElfNN_Rel relocations. 
DT_RELSZ=18	# Total size of ElfNN_Rel relocations. 
DT_RELENT=19	# Size of each ElfNN_Rel relocation. 
DT_PLTREL=20	# Type of relocation used for PLT. 
DT_DEBUG=21	# Reserved (not used). 
DT_TEXTREL=22	# Indicates there may be relocations in
				   # non-writable segments. [sup] 
DT_JMPREL=23	# Address of PLT relocations. 
DT_BIND_NOW=24	# [sup] 
DT_INIT_ARRAY=25	# Address of the array of pointers to
				   # initialization functions 
DT_FINI_ARRAY=26	# Address of the array of pointers to
				   # termination functions 
DT_INIT_ARRAYSZ=27	# Size in bytes of the array of
				   # initialization functions. 
DT_FINI_ARRAYSZ=28	# Size in bytes of the array of
				   # terminationfunctions. 
DT_RUNPATH=29	# String table offset of a null-terminated
				   # library search path string. 
DT_FLAGS=30	# Object specific flag values. 
DT_ENCODING=32	# Values greater than or equal to DT_ENCODING
				   # and less than DT_LOOS follow the rules for
				   # the interpretation of the d_un union
				   # as follows: even == 'd_ptr', even == 'd_val'
				   # or none 
DT_PREINIT_ARRAY=32	# Address of the array of pointers to
				   # pre-initialization functions. 
DT_PREINIT_ARRAYSZ=33	# Size in bytes of the array of
				   # pre-initialization functions. 

DT_COUNT=33	# Number of defined d_tag values. 

DT_LOOS=0x6000000d	# First OS-specific 
DT_HIOS=0x6fff0000	# Last OS-specific 
DT_LOPROC=0x70000000	# First processor-specific type. 
DT_HIPROC=0x7fffffff	# Last processor-specific type. 

# Values for DT_FLAGS 
DF_ORIGIN=0x0001	# Indicates that the object being loaded may
				   # make reference to the $ORIGIN substitution
				   # string 
DF_SYMBOLIC=0x0002	# Indicates "symbolic" linking. 
DF_TEXTREL=0x0004	# Indicates there may be relocations in
				   # non-writable segments. 
DF_BIND_NOW=0x0008	# Indicates that the dynamic linker should
				   # process all relocations for the object
				   # containing this entry before transferring
				   # control to the program. 
DF_STATIC_TLS=0x0010	# Indicates that the shared object or
				   # executable contains code using a static
				   # thread-local storage scheme. 

# Values for n_type.  Used in core files. 
NT_PRSTATUS=1	# Process status. 
NT_FPREGSET=2	# Floating point registers. 
NT_PRPSINFO=3	# Process state info. 

# Symbol Binding - ELFNN_ST_BIND - st_info 
STB_LOCAL=0	# Local symbol 
STB_GLOBAL=1	# Global symbol 
STB_WEAK=2	# like global - lower precedence 
STB_LOPROC=13	# reserved range for processor 
STB_HIPROC=15	#  specific symbol bindings 

# Symbol type - ELFNN_ST_TYPE - st_info 
STT_NOTYPE=0	# Unspecified type. 
STT_OBJECT=1	# Data object. 
STT_FUNC=2	# Function. 
STT_SECTION=3	# Section. 
STT_FILE=4	# Source file. 
STT_TLS=6	# TLS object. 
STT_LOPROC=13	# reserved range for processor 
STT_HIPROC=15	#  specific symbol types 

# Special symbol table indexes. 
STN_UNDEF=0	# Undefined symbol index. 
